# mapargs
Generate boilerplate that maps arguments.


[//]: # (start:shell`python -m mapargs.command_line --help`)
usage: mapargs [-h] infile

positional arguments:
  infile

optional arguments:
  -h, --help  show this help message and exit

[//]: # (end)
